      SUBROUTINE NEWLINE
C      PRINT *,' '
      RETURN
      END
